'use client'

import {
  Card,
  CardContent,
  CardHeader,
  CardTitle,
} from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Button } from "@/components/ui/button"

import { useRef, useEffect } from "react"
import { useRouter } from 'next/navigation'
import { setCookie, getCookie } from "@/lib/utils"

export default function Signin() {
  const router = useRouter()
  const usernameField = useRef<HTMLInputElement>(null)
  const passwordField = useRef<HTMLInputElement>(null)

  useEffect(() => {
    if(getCookie('JWT') != "") {
      router.refresh()
      router.push('/')
    }
  }, [])

  async function signIn() {
    const data = {
      "email": usernameField.current!.value,
      "password": passwordField.current!.value
    }
    console.log(usernameField.current!.value + " - " + passwordField.current!.value)
    const response = await fetch("/api/auth/signin",
                                {
                                  method: "post",
                                  body: JSON.stringify(data)
                                })
    if(response.status == 200) {
      const responseData = await response.json()
      setCookie('JWT', responseData["JWT"], 7)
      const base_url = window.location.origin
      window.location.replace(base_url)
    }
  }

  return (
    <>
      <div className="flex flex-col items-center mt-24" >
        <Card className="w-full max-w-xs">
          <CardHeader>
            <CardTitle>Connectez vous</CardTitle>
          </CardHeader>
          <CardContent className="flex flex-col gap-4">
            <Input ref={usernameField} placeholder="Nom d'utilisateur·rice" />
            <Input ref={passwordField} placeholder="Mot de passe" type="password"/>
            <Button onClick={signIn} className="w-auto">Connexion</Button>
          </CardContent>
        </Card>
      </div>
    </>
  );
}
